@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_log import log as logging
+import six
 
 from sahara.api import acl
-from sahara.service import api
+from sahara.service.api import v10 as api
 from sahara.service import validation as v
 from sahara.service.validations import cluster_template_schema as ct_schema
 from sahara.service.validations import cluster_templates as v_ct
@@ -30,8 +30,6 @@ from sahara.service.validations import plugins as v_p
 import sahara.utils.api as u
 
 
-LOG = logging.getLogger(__name__)
-
 rest = u.Rest('v10', __name__)
 
 
@@ -39,9 +37,12 @@ rest = u.Rest('v10', __name__)
 
 @rest.get('/clusters')
 @acl.enforce("data-processing:clusters:get_all")
+@v.check_exists(api.get_cluster, 'marker')
+@v.validate(None, v.validate_pagination_limit,
+            v.validate_sorting_clusters)
 def clusters_list():
-    return u.render(clusters=[c.to_dict() for c in api.get_clusters(
-        **u.get_request_args().to_dict())])
+    result = api.get_clusters(**u.get_request_args().to_dict())
+    return u.render(res=result, name='clusters')
 
 
 @rest.post('/clusters')
@@ -72,7 +73,8 @@ def clusters_scale(cluster_id, data):
 @v.check_exists(api.get_cluster, 'cluster_id')
 def clusters_get(cluster_id):
     data = u.get_request_args()
-    show_events = unicode(data.get('show_progress', 'false')).lower() == 'true'
+    show_events = six.text_type(
+        data.get('show_progress', 'false')).lower() == 'true'
     return u.to_wrapped_dict(api.get_cluster, cluster_id, show_events)
 
 
@@ -97,10 +99,14 @@ def clusters_delete(cluster_id):
 
 @rest.get('/cluster-templates')
 @acl.enforce("data-processing:cluster-templates:get_all")
+@v.check_exists(api.get_cluster_template, 'marker')
+@v.validate(None, v.validate_pagination_limit,
+            v.validate_sorting_cluster_templates)
 def cluster_templates_list():
-    return u.render(
-        cluster_templates=[t.to_dict() for t in api.get_cluster_templates(
-            **u.get_request_args().to_dict())])
+    result = api.get_cluster_templates(
+        **u.get_request_args().to_dict())
+
+    return u.render(res=result, name='cluster_templates')
 
 
 @rest.post('/cluster-templates')
@@ -141,11 +147,13 @@ def cluster_templates_delete(cluster_template_id):
 
 @rest.get('/node-group-templates')
 @acl.enforce("data-processing:node-group-templates:get_all")
+@v.check_exists(api.get_node_group_template, 'marker')
+@v.validate(None, v.validate_pagination_limit,
+            v.validate_sorting_node_group_templates)
 def node_group_templates_list():
-    return u.render(
-        node_group_templates=[t.to_dict()
-                              for t in api.get_node_group_templates(
-                              **u.get_request_args().to_dict())])
+    result = api.get_node_group_templates(
+        **u.get_request_args().to_dict())
+    return u.render(res=result, name='node_group_templates')
 
 
 @rest.post('/node-group-templates')
@@ -183,6 +191,31 @@ def node_group_templates_delete(node_group_template_id):
     return u.render()
 
 
+def _node_group_template_export_helper(template):
+    template.pop('id')
+    template.pop('updated_at')
+    template.pop('created_at')
+    template.pop('tenant_id')
+    template.pop('is_default')
+    template['flavor_id'] = '{flavor_id}'
+    template['security_groups'] = '{security_groups}'
+    template['image_id'] = '{image_id}'
+    template['floating_ip_pool'] = '{floating_ip_pool}'
+
+
+@rest.get('/node-group-templates/<node_group_template_id>/export')
+@acl.enforce("data-processing:node-group-templates:get")
+@v.check_exists(api.get_node_group_template, 'node_group_template_id')
+def node_group_template_export(node_group_template_id):
+    content = u.to_wrapped_dict_no_render(
+        api.export_node_group_template, node_group_template_id)
+    _node_group_template_export_helper(content['node_group_template'])
+    res = u.render(content)
+    res.headers.add('Content-Disposition', 'attachment',
+                    filename='node_group_template.json')
+    return res
+
+
 # Plugins ops
 
 @rest.get('/plugins')
@@ -205,13 +238,22 @@ def plugins_get_version(plugin_name, version):
     return u.render(api.get_plugin(plugin_name, version).wrapped_dict)
 
 
+@rest.patch('/plugins/<plugin_name>')
+@acl.enforce("data-processing:plugins:patch")
+@v.check_exists(api.get_plugin, plugin_name='plugin_name')
+@v.validate(v_p.plugin_update_validation_jsonschema(), v_p.check_plugin_update)
+def plugins_update(plugin_name, data):
+    return u.render(api.update_plugin(plugin_name, data).wrapped_dict)
+
+
 @rest.post_file('/plugins/<plugin_name>/<version>/convert-config/<name>')
 @acl.enforce("data-processing:plugins:convert_config")
 @v.check_exists(api.get_plugin, plugin_name='plugin_name', version='version')
-@v.validate(v_p.CONVERT_TO_TEMPLATE_SCHEMA, v_p.check_convert_to_template)
+@v.validate(None, v_p.check_convert_to_template)
 def plugins_convert_to_cluster_template(plugin_name, version, name, data):
-    return u.to_wrapped_dict(
-        api.convert_to_cluster_template, plugin_name, version, name, data)
+    # There is no plugins that supports converting to cluster template
+    # The last plugin with support of that is no longer supported
+    pass
 
 
 # Image Registry ops
@@ -228,7 +270,7 @@ def images_list():
 @acl.enforce("data-processing:images:get")
 @v.check_exists(api.get_image, id='image_id')
 def images_get(image_id):
-    return u.render(api.get_registered_image(id=image_id).wrapped_dict)
+    return u.render(api.get_registered_image(image_id=image_id).wrapped_dict)
 
 
 @rest.post('/images/<image_id>')
