@@ -22,8 +22,10 @@ from oslo_log import log
 
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.plugins import base as plugins_base
+from sahara.plugins import opts as plugins_base
 from sahara.service.castellan import config as castellan
+from sahara.service.edp.data_sources import opts as data_source
+from sahara.service.edp.job_binaries import opts as job_binary
 from sahara.topology import topology_helper
 from sahara.utils.notification import sender
 from sahara.utils.openstack import cinder
@@ -33,8 +35,9 @@ from sahara import version
 
 
 cli_opts = [
-    cfg.StrOpt('host', default='',
-               help='Hostname or IP address that will be used to listen on.'),
+    cfg.HostAddressOpt('host', default='0.0.0.0',
+                       help='Hostname or IP address that will be used '
+                            'to listen on.'),
     cfg.PortOpt('port', default=8386,
                 help='Port that will be used to listen on.'),
     cfg.BoolOpt('log-exchange', default=False,
@@ -51,7 +54,10 @@ edp_opts = [
                default=300,
                help='Timeout for canceling job execution (in seconds). '
                     'Sahara will try to cancel job execution during '
-                    'this time.')
+                    'this time.'),
+    cfg.BoolOpt('edp_internal_db_enabled',
+                default=True,
+                help='Use Sahara internal db to store job binaries.')
 ]
 
 db_opts = [
@@ -75,7 +81,7 @@ networking_opts = [
                help="The suffix of the node's FQDN. In nova-network that is "
                     "the dhcp_domain config parameter."),
     cfg.BoolOpt('use_neutron',
-                default=False,
+                default=True,
                 help="Use Neutron Networking (False indicates the use of Nova "
                      "networking)."),
     cfg.BoolOpt('use_namespaces',
@@ -85,8 +91,8 @@ networking_opts = [
     cfg.BoolOpt('use_rootwrap',
                 default=False,
                 help="Use rootwrap facility to allow non-root users to run "
-                     "the sahara-all server instance and access private "
-                     "network IPs (only valid to use in conjunction with "
+                     "the sahara services and access private network IPs "
+                     "(only valid to use in conjunction with "
                      "use_namespaces=True)"),
     cfg.StrOpt('rootwrap_command',
                default='sudo sahara-rootwrap /etc/sahara/rootwrap.conf',
@@ -94,12 +100,24 @@ networking_opts = [
                     "use_rootwrap=True")
 ]
 
+dns_opts = [
+    cfg.BoolOpt('use_designate',
+                default=False,
+                help='Use Designate for internal and external hostnames '
+                     'resolution'),
+    cfg.ListOpt('nameservers',
+                default=[],
+                help="IP addresses of Designate nameservers. "
+                     "This is required if 'use_designate' is True")
+]
+
 
 CONF = cfg.CONF
 CONF.register_cli_opts(cli_opts)
 CONF.register_opts(networking_opts)
 CONF.register_opts(edp_opts)
 CONF.register_opts(db_opts)
+CONF.register_opts(dns_opts)
 
 log.register_options(CONF)
 
@@ -111,7 +129,7 @@ log.set_defaults(default_log_levels=[
     'sqlalchemy=WARN',
     'boto=WARN',
     'suds=INFO',
-    'keystone=INFO',
+    'keystonemiddleware=WARN',
     'paramiko=WARN',
     'requests=WARN',
     'iso8601=WARN',
@@ -149,6 +167,7 @@ def list_opts():
          itertools.chain(cli_opts,
                          edp_opts,
                          networking_opts,
+                         dns_opts,
                          db_opts,
                          plugins_base.opts,
                          topology_helper.opts,
@@ -164,7 +183,9 @@ def list_opts():
                          heat_engine.heat_engine_opts,
                          templates.heat_engine_opts,
                          ssh_remote.ssh_config_options,
-                         castellan.opts)),
+                         castellan.opts,
+                         data_source.opts,
+                         job_binary.opts)),
         (poll_utils.timeouts.name,
          itertools.chain(poll_utils.timeouts_opts)),
         (api.conductor_group.name,
