@@ -26,7 +26,6 @@ from oslo_log import log as logging
 
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LW
 from sahara.service import sessions
 
 
@@ -52,22 +51,22 @@ class Context(context.RequestContext):
                  overwrite=True,
                  **kwargs):
         if kwargs:
-            LOG.warning(_LW('Arguments dropped when creating context: '
-                            '{args}').format(args=kwargs))
+            LOG.warning('Arguments dropped when creating context: '
+                        '{args}'.format(args=kwargs))
 
         super(Context, self).__init__(auth_token=auth_token,
                                       user=user_id,
                                       tenant=tenant_id,
                                       is_admin=is_admin,
                                       resource_uuid=resource_uuid,
-                                      request_id=request_id)
+                                      request_id=request_id,
+                                      roles=roles)
         self.service_catalog = service_catalog
         self.username = username
         self.tenant_name = tenant_name
         self.remote_semaphore = remote_semaphore or semaphore.Semaphore(
             CONF.cluster_remote_threshold)
         self.auth_plugin = auth_plugin
-        self.roles = roles
         if overwrite or not hasattr(context._request_store, 'context'):
             self.update_store()
 
@@ -94,20 +93,16 @@ class Context(context.RequestContext):
             overwrite=False)
 
     def to_dict(self):
-        return {
+        d = super(Context, self).to_dict()
+        d.update({
             'user_id': self.user_id,
             'tenant_id': self.tenant_id,
-            'auth_token': self.auth_token,
             'service_catalog': self.service_catalog,
             'username': self.username,
             'tenant_name': self.tenant_name,
             'user_name': self.username,
-            'project_name': self.tenant_name,
-            'is_admin': self.is_admin,
-            'roles': self.roles,
-            'resource_uuid': self.resource_uuid,
-            'request_id': self.request_id,
-        }
+            'project_name': self.tenant_name})
+        return d
 
     def is_auth_capable(self):
         return (self.service_catalog and self.auth_token and self.tenant and
@@ -323,5 +318,5 @@ def get_auth_token():
         try:
             cur.auth_token = sessions.cache().token_for_auth(cur.auth_plugin)
         except Exception as e:
-            LOG.warning(_LW("Cannot update token, reason: %s"), e)
+            LOG.warning("Cannot update token, reason: %s", e)
     return cur.auth_token
