@@ -14,11 +14,11 @@
 
 import copy
 import os
-import uuid
 
 import jsonschema
 from oslo_config import cfg
 from oslo_serialization import jsonutils as json
+from oslo_utils import uuidutils
 import six
 
 from sahara import conductor
@@ -167,7 +167,7 @@ def check_cluster_templates_valid(ng_templates, cl_templates):
     # passes JSON validation. We don't have the real uuid yet,
     # but this will allow the validation test.
     if ng_templates:
-        dummy_uuid = uuid.uuid4()
+        dummy_uuid = uuidutils.generate_uuid()
         ng_ids = {ng["template"]["name"]: dummy_uuid for ng in ng_templates}
     else:
         ng_ids = {}
@@ -298,8 +298,8 @@ def process_files(dirname, files):
                         data = fp.read()
                         template = json.loads(data)
                     except ValueError as e:
-                        LOG.warning("Error processing {path}, {reason}".format(
-                            path=fpath, reason=e))
+                        LOG.warning("Error processing {path}, "
+                                    "{reason}".format(path=fpath, reason=e))
                         raise Handled("error processing files")
 
                     # If this file doesn't contain basic fields, skip it.
@@ -388,12 +388,13 @@ def delete_node_group_template(ctx, template, rollback=False):
 
     try:
         conductor.API.node_group_template_destroy(ctx, template["id"],
-                                                  ignore_default=True)
+                                                  ignore_prot_on_def=True)
     except Exception as e:
-        LOG.warning("Deletion of node group template {info} failed{rollback}"
-                    ", {reason}".format(info=u.name_and_id(template),
-                                        reason=e,
-                                        rollback=rollback_msg))
+        LOG.warning("Deletion of node group template {info} "
+                    "failed{rollback}, {reason}".format(
+                        info=u.name_and_id(template),
+                        reason=e,
+                        rollback=rollback_msg))
     else:
         LOG.info("Deleted node group template {info}{rollback}".format(
             info=u.name_and_id(template), rollback=rollback_msg))
@@ -410,16 +411,15 @@ def reverse_node_group_template_updates(ctx, update_info):
         try:
             conductor.API.node_group_template_update(ctx,
                                                      template["id"], values,
-                                                     ignore_default=True)
+                                                     ignore_prot_on_def=True)
         except Exception as e:
             LOG.warning("Rollback of update for node group "
                         "template {info} failed, {reason}".format(
                             info=u.name_and_id(template),
                             reason=e))
         else:
-            LOG.info("Rolled back update for "
-                     "node group template {info}".format(
-                         info=u.name_and_id(template)))
+            LOG.info("Rolled back update for node group "
+                     "template {info}".format(info=u.name_and_id(template)))
 
 
 def add_node_group_templates(ctx, node_groups):
@@ -454,7 +454,7 @@ def add_node_group_templates(ctx, node_groups):
                 # mark it as updated.
                 try:
                     template = conductor.API.node_group_template_update(
-                        ctx, current['id'], template, ignore_default=True)
+                        ctx, current['id'], template, ignore_prot_on_def=True)
                 except Exception as e:
                     LOG.warning("Update of node group template {info} "
                                 "failed, {reason}".format(
@@ -465,9 +465,8 @@ def add_node_group_templates(ctx, node_groups):
                 if template['updated_at'] != current['updated_at']:
                     ng_info["updated"].append((template, updated_fields))
                     LOG.info("Updated node group template {info} "
-                             "from {path}".format(
-                                 info=u.name_and_id(template),
-                                 path=ng["path"]))
+                             "from {path}".format(info=u.name_and_id(template),
+                                                  path=ng["path"]))
                 else:
                     LOG.debug("No change to node group template {info} "
                               "from {path}".format(
@@ -489,7 +488,7 @@ def add_node_group_templates(ctx, node_groups):
                          "from {path}".format(info=u.name_and_id(template),
                                               path=ng["path"]))
 
-            # For the purposes of substituion we need a dict of id by name
+            # For the purposes of substitution we need a dict of id by name
             ng_info["ids"][template['name']] = template['id']
 
     except Handled:
@@ -526,7 +525,7 @@ def delete_cluster_template(ctx, template, rollback=False):
 
     try:
         conductor.API.cluster_template_destroy(ctx, template["id"],
-                                               ignore_default=True)
+                                               ignore_prot_on_def=True)
     except Exception as e:
         LOG.warning("Deletion of cluster template {info} failed{rollback}"
                     ", {reason}".format(info=u.name_and_id(template),
@@ -548,16 +547,15 @@ def reverse_cluster_template_updates(ctx, update_info):
         try:
             conductor.API.cluster_template_update(ctx,
                                                   template["id"], values,
-                                                  ignore_default=True)
+                                                  ignore_prot_on_def=True)
         except Exception as e:
             LOG.warning("Rollback of update for cluster "
                         "template {info} failed, {reason}".format(
                             info=u.name_and_id(template),
                             reason=e))
         else:
-            LOG.info("Rolled back update for "
-                     "cluster template {info}".format(
-                         info=u.name_and_id(template)))
+            LOG.info("Rolled back update for cluster "
+                     "template {info}".format(info=u.name_and_id(template)))
 
 
 def add_cluster_templates(ctx, clusters, ng_dict):
@@ -617,7 +615,7 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                 # Probably a bug
                 try:
                     template = conductor.API.cluster_template_update(
-                        ctx, current['id'], template, ignore_default=True)
+                        ctx, current['id'], template, ignore_prot_on_def=True)
                 except Exception as e:
                     LOG.warning("Update of cluster template {info} "
                                 "failed, {reason}".format(
@@ -627,9 +625,8 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                 if template['updated_at'] != current['updated_at']:
                     updated.append((template, updated_fields))
                     LOG.info("Updated cluster template {info} "
-                             "from {path}".format(
-                                 info=u.name_and_id(template),
-                                 path=cl['path']))
+                             "from {path}".format(info=u.name_and_id(template),
+                                                  path=cl['path']))
                 else:
                     LOG.debug("No change to cluster template {info} "
                               "from {path}".format(info=u.name_and_id(current),
@@ -647,8 +644,9 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                     raise Handled()
 
                 created.append(template)
-                LOG.info("Created cluster template {info} from {path}".format(
-                    info=u.name_and_id(template), path=cl['path']))
+                LOG.info("Created cluster template {info} "
+                         "from {path}".format(info=u.name_and_id(template),
+                                              path=cl['path']))
 
     except Handled:
         error = do_reversals(created, updated)
@@ -748,12 +746,13 @@ def do_delete():
 def do_node_group_template_delete():
     ctx = Context(tenant_id=CONF.command.tenant_id)
 
-    t = u.find_node_group_template_by_name(ctx, CONF.command.template_name)
+    template_name = CONF.command.template_name
+    t = u.find_node_group_template_by_name(ctx, template_name)
     if t:
         delete_node_group_template(ctx, t)
     else:
         LOG.warning("Deletion of node group template {name} failed, "
-                    "no such template".format(name=CONF.command.template_name))
+                    "no such template".format(name=template_name))
 
 
 def do_node_group_template_delete_by_id():
@@ -766,7 +765,8 @@ def do_node_group_template_delete_by_id():
             delete_node_group_template(ctx, t)
         else:
             LOG.warning("Deletion of node group template {info} skipped, "
-                        "not a default template".format(info=u.name_and_id(t)))
+                        "not a default template".format(
+                            info=u.name_and_id(t)))
     else:
         LOG.warning("Deletion of node group template {id} failed, "
                     "no such template".format(id=CONF.command.id))
@@ -775,12 +775,13 @@ def do_node_group_template_delete_by_id():
 def do_cluster_template_delete():
     ctx = Context(tenant_id=CONF.command.tenant_id)
 
-    t = u.find_cluster_template_by_name(ctx, CONF.command.template_name)
+    template_name = CONF.command.template_name
+    t = u.find_cluster_template_by_name(ctx, template_name)
     if t:
         delete_cluster_template(ctx, t)
     else:
         LOG.warning("Deletion of cluster template {name} failed, "
-                    "no such template".format(name=CONF.command.template_name))
+                    "no such template".format(name=template_name))
 
 
 def do_cluster_template_delete_by_id():
@@ -793,7 +794,8 @@ def do_cluster_template_delete_by_id():
             delete_cluster_template(ctx, t)
         else:
             LOG.warning("Deletion of cluster template {info} skipped, "
-                        "not a default template".format(info=u.name_and_id(t)))
+                        "not a default template".format(
+                            info=u.name_and_id(t)))
     else:
         LOG.warning("Deletion of cluster template {id} failed, "
                     "no such template".format(id=CONF.command.id))
