@@ -23,6 +23,7 @@ from sahara.plugins.ambari import deploy
 from sahara.plugins.ambari import edp_engine
 from sahara.plugins.ambari import health
 from sahara.plugins.ambari import validation
+from sahara.plugins import kerberos
 from sahara.plugins import provisioning as p
 from sahara.plugins import utils as plugin_utils
 from sahara.swift import swift_helper
@@ -37,10 +38,12 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
         return "HDP Plugin"
 
     def get_description(self):
-        return _("HDP plugin with Ambari")
+        return _("The Ambari Sahara plugin provides the ability to launch "
+                 "clusters with Hortonworks Data Platform (HDP) on OpenStack "
+                 "using Apache Ambari")
 
     def get_versions(self):
-        return ["2.3"]
+        return ["2.3", "2.4", "2.5"]
 
     def get_node_processes(self, hadoop_version):
         return {
@@ -69,10 +72,13 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
                 p_common.APP_TIMELINE_SERVER, p_common.HISTORYSERVER,
                 p_common.NODEMANAGER, p_common.RESOURCEMANAGER],
             p_common.ZOOKEEPER_SERVICE: [p_common.ZOOKEEPER_SERVER],
+            'Kerberos': [],
         }
 
     def get_configs(self, hadoop_version):
-        return configs.load_configs(hadoop_version)
+        cfgs = kerberos.get_config_list()
+        cfgs.extend(configs.load_configs(hadoop_version))
+        return cfgs
 
     def configure_cluster(self, cluster):
         deploy.disable_repos(cluster)
@@ -83,18 +89,23 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
         cluster = conductor.cluster_get(context.ctx(), cluster.id)
         deploy.wait_host_registration(cluster,
                                       plugin_utils.get_instances(cluster))
+        deploy.prepare_kerberos(cluster)
         deploy.set_up_hdp_repos(cluster)
+        deploy.resolve_package_conflicts(cluster)
         deploy.create_blueprint(cluster)
 
     def start_cluster(self, cluster):
         self._set_cluster_info(cluster)
         deploy.start_cluster(cluster)
-        swift_helper.install_ssl_certs(plugin_utils.get_instances(cluster))
+        cluster_instances = plugin_utils.get_instances(cluster)
+        swift_helper.install_ssl_certs(cluster_instances)
+        deploy.add_hadoop_swift_jar(cluster_instances)
         deploy.prepare_hive(cluster)
+        deploy.deploy_kerberos_principals(cluster)
 
     def _set_cluster_info(self, cluster):
         ambari_ip = plugin_utils.get_instance(
-            cluster, p_common.AMBARI_SERVER).management_ip
+            cluster, p_common.AMBARI_SERVER).get_ip_or_dns_name()
         ambari_port = "8080"
         info = {
             p_common.AMBARI_SERVER: {
@@ -109,53 +120,54 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
         for idx, namenode in enumerate(nns):
             info[p_common.NAMENODE][
                 "Web UI %s" % (idx + 1)] = (
-                "http://%s:50070" % namenode.management_ip)
+                "http://%s:50070" % namenode.get_ip_or_dns_name())
 
         rms = plugin_utils.get_instances(cluster, p_common.RESOURCEMANAGER)
         info[p_common.RESOURCEMANAGER] = {}
         for idx, resourcemanager in enumerate(rms):
             info[p_common.RESOURCEMANAGER][
                 "Web UI %s" % (idx + 1)] = (
-                "http://%s:8088" % resourcemanager.management_ip)
+                "http://%s:8088" % resourcemanager.get_ip_or_dns_name())
 
         historyserver = plugin_utils.get_instance(cluster,
                                                   p_common.HISTORYSERVER)
         if historyserver:
             info[p_common.HISTORYSERVER] = {
-                "Web UI": "http://%s:19888" % historyserver.management_ip
+                "Web UI": "http://%s:19888" %
+                          historyserver.get_ip_or_dns_name()
             }
         atlserver = plugin_utils.get_instance(cluster,
                                               p_common.APP_TIMELINE_SERVER)
         if atlserver:
             info[p_common.APP_TIMELINE_SERVER] = {
-                "Web UI": "http://%s:8188" % atlserver.management_ip
+                "Web UI": "http://%s:8188" % atlserver.get_ip_or_dns_name()
             }
         oozie = plugin_utils.get_instance(cluster, p_common.OOZIE_SERVER)
         if oozie:
             info[p_common.OOZIE_SERVER] = {
-                "Web UI": "http://%s:11000/oozie" % oozie.management_ip
+                "Web UI": "http://%s:11000/oozie" % oozie.get_ip_or_dns_name()
             }
         hbase_master = plugin_utils.get_instance(cluster,
                                                  p_common.HBASE_MASTER)
         if hbase_master:
             info[p_common.HBASE_MASTER] = {
-                "Web UI": "http://%s:60010" % hbase_master.management_ip
+                "Web UI": "http://%s:60010" % hbase_master.get_ip_or_dns_name()
             }
         falcon = plugin_utils.get_instance(cluster, p_common.FALCON_SERVER)
         if falcon:
             info[p_common.FALCON_SERVER] = {
-                "Web UI": "http://%s:15000" % falcon.management_ip
+                "Web UI": "http://%s:15000" % falcon.get_ip_or_dns_name()
             }
         storm_ui = plugin_utils.get_instance(cluster, p_common.STORM_UI_SERVER)
         if storm_ui:
             info[p_common.STORM_UI_SERVER] = {
-                "Web UI": "http://%s:8744" % storm_ui.management_ip
+                "Web UI": "http://%s:8744" % storm_ui.get_ip_or_dns_name()
             }
         ranger_admin = plugin_utils.get_instance(cluster,
                                                  p_common.RANGER_ADMIN)
         if ranger_admin:
             info[p_common.RANGER_ADMIN] = {
-                "Web UI": "http://%s:6080" % ranger_admin.management_ip,
+                "Web UI": "http://%s:6080" % ranger_admin.get_ip_or_dns_name(),
                 "Username": "admin",
                 "Password": "admin"
             }
@@ -163,7 +175,7 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
                                              p_common.SPARK_JOBHISTORYSERVER)
         if spark_hs:
             info[p_common.SPARK_JOBHISTORYSERVER] = {
-                "Web UI": "http://%s:18080" % spark_hs.management_ip
+                "Web UI": "http://%s:18080" % spark_hs.get_ip_or_dns_name()
             }
         info.update(cluster.info.to_dict())
         ctx = context.ctx()
@@ -174,18 +186,24 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
         validation.validate(cluster.id)
 
     def scale_cluster(self, cluster, instances):
+        deploy.prepare_kerberos(cluster, instances)
         deploy.setup_agents(cluster, instances)
         cluster = conductor.cluster_get(context.ctx(), cluster.id)
         deploy.wait_host_registration(cluster, instances)
+        deploy.resolve_package_conflicts(cluster, instances)
         deploy.add_new_hosts(cluster, instances)
         deploy.manage_config_groups(cluster, instances)
         deploy.manage_host_components(cluster, instances)
+        deploy.configure_rack_awareness(cluster, instances)
         swift_helper.install_ssl_certs(instances)
+        deploy.add_hadoop_swift_jar(instances)
+        deploy.deploy_kerberos_principals(cluster, instances)
 
     def decommission_nodes(self, cluster, instances):
         deploy.decommission_hosts(cluster, instances)
         deploy.remove_services_from_hosts(cluster, instances)
         deploy.restart_nns_and_rms(cluster)
+        deploy.cleanup_config_groups(cluster, instances)
 
     def validate_scaling(self, cluster, existing, additional):
         validation.validate(cluster.id)
