@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_utils import uuidutils
+
 import abc
 import collections
 import copy
@@ -54,20 +56,20 @@ def transform_exception(from_type, to_type, transform_func=None):
     return decorator
 
 
-def validate_instance(instance, validators, reconcile=True, **kwargs):
+def validate_instance(instance, validators, test_only=False, **kwargs):
     """Runs all validators against the specified instance.
 
     :param instance: An instance to validate.
     :param validators: A sequence of ImageValidators.
-    :param reconcile: If false, all validators will only verify that a
-        desired state is present, and fail if it is not. If true, all
+    :param test_only: If true, all validators will only verify that a
+        desired state is present, and fail if it is not. If false, all
         validators will attempt to enforce the desired state if possible,
         and succeed if this enforcement succeeds.
     :raises ImageValidationError: If validation fails.
     """
     with instance.remote() as remote:
         for validator in validators:
-            validator.validate(remote, reconcile=reconcile, **kwargs)
+            validator.validate(remote, test_only=test_only, **kwargs)
 
 
 class ImageArgument(object):
@@ -110,7 +112,7 @@ class ImageArgument(object):
         """Constructs and returns a set of arguments from a specification.
 
         :param spec: The specification for the argument set.
-        :return A dict of arguments built to the specification.
+        :return: A dict of arguments built to the specification.
         """
 
         jsonschema.validate(spec, cls.SPEC_SCHEMA)
@@ -120,7 +122,7 @@ class ImageArgument(object):
                                arg.get('required'),
                                arg.get('choices'))
                      for name, arg in six.iteritems(spec)}
-        reserved_names = ['distro', 'reconcile']
+        reserved_names = ['distro', 'test_only']
         for name, arg in six.iteritems(arguments):
             if name in reserved_names:
                 raise p_ex.ImageValidationSpecificationError(
@@ -150,12 +152,12 @@ class ImageValidator(object):
     """Validates the image spawned to an instance via a set of rules."""
 
     @abc.abstractmethod
-    def validate(self, remote, reconcile=True, **kwargs):
+    def validate(self, remote, test_only=False, **kwargs):
         """Validates the image.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :raises ImageValidationError: If validation fails.
@@ -168,7 +170,7 @@ class SaharaImageValidatorBase(ImageValidator):
     """Base class for Sahara's native image validation."""
 
     DISTRO_KEY = 'distro'
-    RECONCILE_KEY = 'reconcile'
+    TEST_ONLY_KEY = 'test_only'
 
     ORDERED_VALIDATORS_SCHEMA = {
         "type": "array",
@@ -183,6 +185,7 @@ class SaharaImageValidatorBase(ImageValidator):
         'centos': 'redhat',
         'centos7': 'redhat',
         'fedora': 'redhat',
+        'redhat': 'redhat',
         'redhatenterpriseserver': 'redhat',
         'ubuntu': 'debian'
     }
@@ -194,7 +197,7 @@ class SaharaImageValidatorBase(ImageValidator):
         :param custom_validator_map: A map of validator names and classes to
             add to the ones Sahara provides by default. These will take
             precedence over the base validators in case of key overlap.
-        :return A map of validator names and classes.
+        :return: A map of validator names and classes.
         """
         default_validator_map = {
             'package': SaharaPackageValidator,
@@ -218,7 +221,7 @@ class SaharaImageValidatorBase(ImageValidator):
         :param resource_roots: The roots from which relative paths to
             resources (scripts and such) will be referenced. Any resource will
             be pulled from the first path in the list at which a file exists.
-        :return A SaharaImageValidator built to the yaml specification.
+        :return: A SaharaImageValidator built to the yaml specification.
         """
         validator_map = validator_map or {}
         resource_roots = resource_roots or []
@@ -236,7 +239,7 @@ class SaharaImageValidatorBase(ImageValidator):
         :param resource_roots: The roots from which relative paths to
             resources (scripts and such) will be referenced. Any resource will
             be pulled from the first path in the list at which a file exists.
-        :return A validator built to the specification.
+        :return: A validator built to the specification.
         """
         pass
 
@@ -293,22 +296,22 @@ class SaharaImageValidatorBase(ImageValidator):
         def __nonzero__(self):
             return False
 
-    def try_validate(self, remote, reconcile=True,
+    def try_validate(self, remote, test_only=False,
                      image_arguments=None, **kwargs):
         """Attempts to validate, but returns rather than raising on failure.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
             argument name.
-        :return True if successful, ValidationAttemptFailed object if failed.
+        :return: True if successful, ValidationAttemptFailed object if failed.
         """
         try:
             self.validate(
-                remote, reconcile=reconcile,
+                remote, test_only=test_only,
                 image_arguments=image_arguments, **kwargs)
             return True
         except p_ex.ImageValidationError as exc:
@@ -346,7 +349,7 @@ class SaharaImageValidator(SaharaImageValidatorBase):
         :param resource_roots: The roots from which relative paths to
             resources (scripts and such) will be referenced. Any resource will
             be pulled from the first path in the list at which a file exists.
-        :return A SaharaImageValidator containing all specified validators.
+        :return: A SaharaImageValidator containing all specified validators.
         """
         jsonschema.validate(spec, cls.SPEC_SCHEMA)
         arguments_spec = spec.get('arguments', {})
@@ -367,7 +370,7 @@ class SaharaImageValidator(SaharaImageValidatorBase):
         self.arguments = arguments
 
     @transform_exception(ex.RemoteCommandException, p_ex.ImageValidationError)
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate the image.
 
@@ -375,8 +378,8 @@ class SaharaImageValidator(SaharaImageValidatorBase):
         steps such as distro discovery.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
@@ -402,7 +405,7 @@ class SaharaImageValidator(SaharaImageValidatorBase):
                 else:
                     argument_values[name] = value
         argument_values[self.DISTRO_KEY] = remote.get_os_distrib()
-        self.validator.validate(remote, reconcile=reconcile,
+        self.validator.validate(remote, test_only=test_only,
                                 image_arguments=argument_values)
 
 
@@ -495,17 +498,17 @@ class SaharaPackageValidator(SaharaImageValidatorBase):
         self.packages = packages
 
     @transform_exception(ex.RemoteCommandException, p_ex.ImageValidationError)
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate package installation on the image.
 
-        Even if reconcile=True, attempts to verify previous package
+        Even if test_only=False, attempts to verify previous package
         installation offline before using networked tools to validate or
         install new packages.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
@@ -522,7 +525,7 @@ class SaharaPackageValidator(SaharaImageValidatorBase):
             check(self, remote)
         except (ex.SubprocessException, ex.RemoteCommandException,
                 RuntimeError):
-            if reconcile:
+            if not test_only:
                 install(self, remote)
                 check(self, remote)
             else:
@@ -559,7 +562,7 @@ class SaharaPackageValidator(SaharaImageValidatorBase):
 class SaharaScriptValidator(SaharaImageValidatorBase):
     """A validator that runs a script on the instance."""
 
-    _DEFAULT_ENV_VARS = [SaharaImageValidatorBase.RECONCILE_KEY,
+    _DEFAULT_ENV_VARS = [SaharaImageValidatorBase.TEST_ONLY_KEY,
                          SaharaImageValidatorBase.DISTRO_KEY]
 
     SPEC_SCHEMA = {
@@ -651,35 +654,37 @@ class SaharaScriptValidator(SaharaImageValidatorBase):
         self.output_var = output_var
 
     @transform_exception(ex.RemoteCommandException, p_ex.ImageValidationError)
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate by running a script on the image.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
             argument name.
-            Note that the key SIV_RECONCILE will be set to 1 if the script
-            should reconcile and 0 otherwise; all scripts should act on this
+            Note that the key SIV_TEST_ONLY will be set to 1 if the script
+            should test_only and 0 otherwise; all scripts should act on this
             input if possible. The key SIV_DISTRO will also contain the
             distro representation, per `lsb_release -is`.
         :raises ImageValidationError: If validation fails.
         """
+
         arguments = copy.deepcopy(image_arguments)
-        arguments[self.RECONCILE_KEY] = 1 if reconcile else 0
+        arguments[self.TEST_ONLY_KEY] = 1 if test_only else 0
         script = "\n".join(["%(env_vars)s",
-                            "bash <<_SIV_",
-                            "%(script)s",
-                            "_SIV_"])
+                            "%(script)s"])
         env_vars = "\n".join("export %s=%s" % (key, value) for (key, value)
-                             in six.iteritems(image_arguments)
+                             in six.iteritems(arguments)
                              if key in self.env_vars)
         script = script % {"env_vars": env_vars,
                            "script": self.script_contents}
-        code, stdout = _sudo(remote, script)
+        path = '/tmp/%s.sh' % uuidutils.generate_uuid()
+        remote.write_file_to(path, script, run_as_root=True)
+        _sudo(remote, 'chmod +x %s' % path)
+        code, stdout = _sudo(remote, '%s' % path)
         if self.output_var:
             image_arguments[self.output_var] = stdout
 
@@ -713,11 +718,11 @@ class SaharaAggregateValidator(SaharaImageValidatorBase):
 class SaharaAnyValidator(SaharaAggregateValidator):
     """A list of validators, only one of which must succeed."""
 
-    def _try_all(self, remote, reconcile=True,
+    def _try_all(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         results = []
         for validator in self.validators:
-            result = validator.try_validate(remote, reconcile=reconcile,
+            result = validator.try_validate(remote, test_only=test_only,
                                             image_arguments=image_arguments,
                                             **kwargs)
             results.append(result)
@@ -725,28 +730,28 @@ class SaharaAnyValidator(SaharaAggregateValidator):
                 break
         return results
 
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate any of the contained validators.
 
-        Note that if reconcile=True, this validator will first run all
-        contained validators using reconcile=False, and succeed immediately
+        Note that if test_only=False, this validator will first run all
+        contained validators using test_only=True, and succeed immediately
         should any pass validation. If all fail, it will only then run them
-        using reconcile=True, and again succeed immediately should any pass.
+        using test_only=False, and again succeed immediately should any pass.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
             argument name.
         :raises ImageValidationError: If validation fails.
         """
-        results = self._try_all(remote, reconcile=False,
+        results = self._try_all(remote, test_only=True,
                                 image_arguments=image_arguments)
-        if reconcile and not any(results):
-            results = self._try_all(remote, reconcile=True,
+        if not test_only and not any(results):
+            results = self._try_all(remote, test_only=False,
                                     image_arguments=image_arguments)
         if not any(results):
             raise p_ex.AllValidationsFailedError(result.exception for result
@@ -756,12 +761,13 @@ class SaharaAnyValidator(SaharaAggregateValidator):
 class SaharaAllValidator(SaharaAggregateValidator):
     """A list of validators, all of which must succeed."""
 
-    def validate(self, remote, reconcile=True, image_arguments=None, **kwargs):
+    def validate(self, remote, test_only=False, image_arguments=None,
+                 **kwargs):
         """Attempts to validate all of the contained validators.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
@@ -769,7 +775,7 @@ class SaharaAllValidator(SaharaAggregateValidator):
         :raises ImageValidationError: If validation fails.
         """
         for validator in self.validators:
-            validator.validate(remote, reconcile=reconcile,
+            validator.validate(remote, test_only=test_only,
                                image_arguments=image_arguments)
 
 
@@ -819,7 +825,7 @@ class SaharaOSCaseValidator(SaharaImageValidatorBase):
         """
         self.distros = distros
 
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate depending on distro.
 
@@ -829,8 +835,8 @@ class SaharaOSCaseValidator(SaharaImageValidatorBase):
         If no keys match, no validators are run, and validation proceeds.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
@@ -843,7 +849,7 @@ class SaharaOSCaseValidator(SaharaImageValidatorBase):
         for distro, validator in self.distros:
             if distro in matches:
                 validator.validate(
-                    remote, reconcile=reconcile,
+                    remote, test_only=test_only,
                     image_arguments=image_arguments)
                 break
 
@@ -902,13 +908,13 @@ class SaharaArgumentCaseValidator(SaharaImageValidatorBase):
         self.argument_name = argument_name
         self.cases = cases
 
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate depending on argument value.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
@@ -922,7 +928,7 @@ class SaharaArgumentCaseValidator(SaharaImageValidatorBase):
         value = image_arguments[arg]
         if value in self.cases:
             self.cases[value].validate(
-                remote, reconcile=reconcile,
+                remote, test_only=test_only,
                 image_arguments=image_arguments)
 
 
@@ -973,13 +979,13 @@ class SaharaArgumentSetterValidator(SaharaImageValidatorBase):
         self.argument_name = argument_name
         self.value = value
 
-    def validate(self, remote, reconcile=True,
+    def validate(self, remote, test_only=False,
                  image_arguments=None, **kwargs):
         """Attempts to validate depending on argument value.
 
         :param remote: A remote socket to the instance.
-        :param reconcile: If false, all validators will only verify that a
-            desired state is present, and fail if it is not. If true, all
+        :param test_only: If true, all validators will only verify that a
+            desired state is present, and fail if it is not. If false, all
             validators will attempt to enforce the desired state if possible,
             and succeed if this enforcement succeeds.
         :param image_arguments: A dictionary of image argument values keyed by
