@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import copy
 import os
 
 from oslo_config import cfg
@@ -20,9 +21,7 @@ from oslo_log import log as logging
 
 from sahara import conductor
 from sahara import context
-from sahara import exceptions
 from sahara.i18n import _
-from sahara.i18n import _LI
 from sahara.plugins import exceptions as ex
 from sahara.plugins import provisioning as p
 from sahara.plugins import recommendations_utils as ru
@@ -59,8 +58,21 @@ class SparkProvider(p.ProvisioningPluginBase):
         return _("This plugin provides an ability to launch Spark on Hadoop "
                  "CDH cluster without any management consoles.")
 
+    def get_labels(self):
+        default = {'enabled': {'status': True}, 'stable': {'status': True}}
+        deprecated = {'enabled': {'status': True},
+                      'deprecated': {'status': True}}
+        result = {'plugin_labels': copy.deepcopy(default)}
+        stable_versions = ['2.1.0', '1.6.0']
+        result['version_labels'] = {
+            version: copy.deepcopy(
+                default if version in stable_versions else deprecated
+                ) for version in self.get_versions()
+        }
+        return result
+
     def get_versions(self):
-        return ['1.3.1', '1.0.0']
+        return ['2.1.0', '1.6.0', '1.3.1']
 
     def get_configs(self, hadoop_version):
         return c_helper.get_plugin_configs()
@@ -69,11 +81,6 @@ class SparkProvider(p.ProvisioningPluginBase):
         return self.processes
 
     def validate(self, cluster):
-        if cluster.hadoop_version == "1.0.0":
-            raise exceptions.DeprecatedException(
-                _("Support for Spark version 1.0.0 is now deprecated and will"
-                  " be removed in the 2016.1 release."))
-
         nn_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "namenode")])
         if nn_count != 1:
@@ -99,9 +106,13 @@ class SparkProvider(p.ProvisioningPluginBase):
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "master")])
 
-        if sm_count != 1:
+        if sm_count < 1:
             raise ex.RequiredServiceMissingException("Spark master")
 
+        if sm_count >= 2:
+            raise ex.InvalidComponentCountException("Spark master", "1",
+                                                    sm_count)
+
         sl_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "slave")])
 
@@ -133,7 +144,7 @@ class SparkProvider(p.ProvisioningPluginBase):
     def _start_spark(self, cluster, sm_instance):
         with remote.get_remote(sm_instance) as r:
             run.start_spark_master(r, self._spark_home(cluster))
-            LOG.info(_LI("Spark service has been started"))
+            LOG.info("Spark service has been started")
 
     def start_cluster(self, cluster):
         nn_instance = utils.get_instance(cluster, "namenode")
@@ -144,8 +155,9 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         # start the data nodes
         self._start_datanode_processes(dn_instances)
+        run.await_datanodes(cluster)
 
-        LOG.info(_LI("Hadoop services have been started"))
+        LOG.info("Hadoop services have been started")
 
         with remote.get_remote(nn_instance) as r:
             r.execute_command("sudo -u hdfs hdfs dfs -mkdir -p /user/$USER/")
@@ -156,7 +168,7 @@ class SparkProvider(p.ProvisioningPluginBase):
         self.start_spark(cluster)
         swift_helper.install_ssl_certs(utils.get_instances(cluster))
 
-        LOG.info(_LI('Cluster has been started successfully'))
+        LOG.info('Cluster has been started successfully')
         self._set_cluster_info(cluster)
 
     def _spark_home(self, cluster):
@@ -394,7 +406,7 @@ class SparkProvider(p.ProvisioningPluginBase):
                 'HDFS', 'dfs.http.address', cluster)
             port = address[address.rfind(':') + 1:]
             info['HDFS'] = {
-                'Web UI': 'http://%s:%s' % (nn.management_ip, port)
+                'Web UI': 'http://%s:%s' % (nn.get_ip_or_dns_name(), port)
             }
             info['HDFS']['NameNode'] = 'hdfs://%s:8020' % nn.hostname()
 
@@ -403,7 +415,8 @@ class SparkProvider(p.ProvisioningPluginBase):
                 'Spark', 'Master webui port', cluster)
             if port is not None:
                 info['Spark'] = {
-                    'Web UI': 'http://%s:%s' % (sp_master.management_ip, port)
+                    'Web UI': 'http://%s:%s' % (
+                        sp_master.get_ip_or_dns_name(), port)
                 }
         ctx = context.ctx()
         conductor.cluster_update(ctx, cluster, {'info': info})
@@ -451,7 +464,7 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         swift_helper.install_ssl_certs(instances)
         run.start_spark_master(r_master, self._spark_home(cluster))
-        LOG.info(_LI("Spark master service has been restarted"))
+        LOG.info("Spark master service has been restarted")
 
     def _get_scalable_processes(self):
         return ["datanode", "slave"]
@@ -502,7 +515,7 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         return None
 
-    def get_edp_job_types(self, versions=[]):
+    def get_edp_job_types(self, versions=None):
         res = {}
         for vers in self.get_versions():
             if not versions or vers in versions:
