@@ -13,7 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
+import copy
+
 from oslo_log import log as logging
 import six
 import yaml
@@ -21,7 +22,6 @@ import yaml
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
 from sahara.plugins import exceptions as ex
 from sahara.plugins import provisioning as p
 from sahara.plugins.storm import config_helper as c_helper
@@ -34,7 +34,6 @@ from sahara.utils import remote
 
 conductor = conductor.API
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 
 class StormProvider(p.ProvisioningPluginBase):
@@ -52,8 +51,20 @@ class StormProvider(p.ProvisioningPluginBase):
             _("This plugin provides an ability to launch Storm "
               "cluster without any management consoles."))
 
+    def get_labels(self):
+        default = {'enabled': {'status': True}, 'stable': {'status': True}}
+        deprecated = {'enabled': {'status': True},
+                      'deprecated': {'status': True}}
+        result = {'plugin_labels': copy.deepcopy(default)}
+        result['version_labels'] = {
+            '1.1.0': copy.deepcopy(default),
+            '1.0.1': copy.deepcopy(default),
+            '0.9.2': copy.deepcopy(deprecated),
+        }
+        return result
+
     def get_versions(self):
-        return ['0.9.2']
+        return ['0.9.2', '1.0.1', '1.1.0']
 
     def get_configs(self, storm_version):
         return c_helper.get_plugin_configs()
@@ -66,9 +77,13 @@ class StormProvider(p.ProvisioningPluginBase):
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "nimbus")])
 
-        if sm_count != 1:
+        if sm_count < 1:
             raise ex.RequiredServiceMissingException("Storm nimbus")
 
+        if sm_count >= 2:
+            raise ex.InvalidComponentCountException("Storm nimbus", "1",
+                                                    sm_count)
+
         sl_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "supervisor")])
 
@@ -98,27 +113,32 @@ class StormProvider(p.ProvisioningPluginBase):
         # start storm slaves
         self._start_slave_processes(sl_instances)
 
-        LOG.info(_LI('Cluster {cluster} has been started successfully').format(
-                 cluster=cluster.name))
+        LOG.info("Cluster {cluster} has been started successfully".format(
+            cluster=cluster.name))
         self._set_cluster_info(cluster)
 
     def get_edp_engine(self, cluster, job_type):
-        if job_type in edp_engine.EdpEngine.get_supported_job_types():
-            return edp_engine.EdpEngine(cluster)
-
+        if job_type in edp_engine.EdpStormEngine.get_supported_job_types():
+            return edp_engine.EdpStormEngine(cluster)
+        if job_type in edp_engine.EdpPyleusEngine.get_supported_job_types():
+            return edp_engine.EdpPyleusEngine(cluster)
         return None
 
     def get_edp_job_types(self, versions=None):
         res = {}
         for vers in self.get_versions():
             if not versions or vers in versions:
-                if edp_engine.EdpEngine.edp_supported(vers):
-                    res[vers] = edp_engine.EdpEngine.get_supported_job_types()
+                storm_engine = edp_engine.EdpStormEngine
+                pyleus_engine = edp_engine.EdpPyleusEngine
+                res[vers] = (storm_engine.get_supported_job_types() +
+                             pyleus_engine.get_supported_job_types())
         return res
 
     def get_edp_config_hints(self, job_type, version):
-        if edp_engine.EdpEngine.edp_supported(version):
-            return edp_engine.EdpEngine.get_possible_job_config(job_type)
+        if edp_engine.EdpStormEngine.edp_supported(version):
+            return edp_engine.EdpStormEngine.get_possible_job_config(job_type)
+        if edp_engine.EdpPyleusEngine.edp_supported(version):
+            return edp_engine.EdpPyleusEngine.get_possible_job_config(job_type)
         return {}
 
     def get_open_ports(self, node_group):
@@ -148,19 +168,22 @@ class StormProvider(p.ProvisioningPluginBase):
 
             config_instances = c_helper.generate_storm_config(
                 st_master.hostname(),
-                zknames)
+                zknames,
+                cluster.hadoop_version)
 
         config = self._convert_dict_to_yaml(config_instances)
         supervisor_conf = c_helper.generate_slave_supervisor_conf()
         nimbus_ui_conf = c_helper.generate_master_supervisor_conf()
         zk_conf = c_helper.generate_zookeeper_conf()
+        pyleus_conf = c_helper.generate_pyleus_config()
 
         for ng in cluster.node_groups:
             extra[ng.id] = {
                 'st_instances': config,
                 'slave_sv_conf': supervisor_conf,
                 'master_sv_conf': nimbus_ui_conf,
-                'zk_conf': zk_conf
+                'zk_conf': zk_conf,
+                'pyleus_conf': pyleus_conf
             }
 
         return extra
@@ -170,8 +193,8 @@ class StormProvider(p.ProvisioningPluginBase):
     def _start_storm_master(self, sm_instance):
         with remote.get_remote(sm_instance) as r:
             run.start_storm_nimbus_and_ui(r)
-            LOG.info(_LI("Storm master at {host} has been started").format(
-                     host=sm_instance.hostname()))
+            LOG.info("Storm master at {host} has been started".format(
+                host=sm_instance.hostname()))
 
     def _start_slave_processes(self, sl_instances):
         if len(sl_instances) == 0:
@@ -259,6 +282,9 @@ class StormProvider(p.ProvisioningPluginBase):
         files_supervisor_master = {
             '/etc/supervisor/supervisord.conf': ng_extra['master_sv_conf']
         }
+        file_pyleus_conf = {
+            '/home/ubuntu/.pyleus.conf': ng_extra['pyleus_conf']
+        }
 
         with remote.get_remote(instance) as r:
             node_processes = instance.node_group.node_processes
@@ -267,6 +293,7 @@ class StormProvider(p.ProvisioningPluginBase):
                 self._push_zk_configs(r, files_zk)
             if 'nimbus' in node_processes:
                 self._push_supervisor_configs(r, files_supervisor_master)
+                self._push_supervisor_configs(r, file_pyleus_conf)
             if 'supervisor' in node_processes:
                 self._push_supervisor_configs(r, files_supervisor)
 
@@ -286,7 +313,7 @@ class StormProvider(p.ProvisioningPluginBase):
             r.write_files_to(files_storm)
 
         if need_zookeeper_update:
-            zk_path = '/opt/zookeeper/zookeeper-3.4.6/conf/zoo.cfg'
+            zk_path = '/opt/zookeeper/zookeeper/conf/zoo.cfg'
             files_zookeeper = {zk_path: ng_extra['zk_conf']}
             self._push_zk_configs(r, files_zookeeper)
 
@@ -298,7 +325,8 @@ class StormProvider(p.ProvisioningPluginBase):
             port = "8080"
 
             info['Strom'] = {
-                'Web UI': 'http://%s:%s' % (st_master.management_ip, port)
+                'Web UI': 'http://%s:%s' % (
+                    st_master.get_ip_or_dns_name(), port)
             }
         ctx = context.ctx()
         conductor.cluster_update(ctx, cluster, {'info': info})
@@ -355,7 +383,7 @@ class StormProvider(p.ProvisioningPluginBase):
         # start storm slaves
         self._start_slave_processes(instances)
         self.rebalance_topology(cluster)
-        LOG.info(_LI("Storm scaling has been started."))
+        LOG.info("Storm scaling has been started.")
 
     def _get_scalable_processes(self):
         return ["supervisor"]
