@@ -19,14 +19,13 @@ import datetime
 import string
 
 from novaclient import exceptions as nova_exceptions
+from oslo_config import cfg
 from oslo_log import log as logging
 import six
 
 from sahara import conductor as c
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
-from sahara.i18n import _LW
 from sahara.service import networks
 from sahara.service import volumes
 from sahara.utils import cluster as cluster_utils
@@ -34,16 +33,19 @@ from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import edp
 from sahara.utils import general as g
 from sahara.utils.openstack import base as b
+from sahara.utils.openstack import images as sahara_images
 from sahara.utils.openstack import nova
 from sahara.utils import poll_utils
 from sahara.utils import remote
 
 LOG = logging.getLogger(__name__)
 conductor = c.API
+CONF = cfg.CONF
 
 
 @six.add_metaclass(abc.ABCMeta)
 class Engine(object):
+
     @abc.abstractmethod
     def create_cluster(self, cluster):
         pass
@@ -70,7 +72,7 @@ class Engine(object):
     def get_node_group_image_username(self, node_group):
         image_id = node_group.get_image_id()
         return b.execute_with_retries(
-            nova.client().images.get, image_id).username
+            sahara_images.image_manager().get, image_id).username
 
     @poll_utils.poll_status('ips_assign_timeout', _("Assign IPs"), sleep=1)
     def _ips_assign(self, ips_assigned, cluster, instances):
@@ -93,8 +95,7 @@ class Engine(object):
         ips_assigned = set()
         self._ips_assign(ips_assigned, cluster, instances)
 
-        LOG.info(
-            _LI("All instances have IPs assigned"))
+        LOG.info("All instances have IPs assigned")
 
         cluster = conductor.cluster_get(context.ctx(), cluster)
         instances = cluster_utils.get_instances(cluster, ips_assigned)
@@ -108,7 +109,7 @@ class Engine(object):
                     tg.spawn("wait-for-ssh-%s" % instance.instance_name,
                              self._wait_until_accessible, instance)
 
-        LOG.info(_LI("All instances are accessible"))
+        LOG.info("All instances are accessible")
 
     @poll_utils.poll_status(
         'wait_until_accessible', _("Wait for instance accessibility"),
@@ -126,9 +127,11 @@ class Engine(object):
                 LOG.debug('Instance is accessible')
                 return True
         except Exception as ex:
-            LOG.debug("Can't login to node, IP: {mgmt_ip}, "
-                      "reason {reason}".format(mgmt_ip=instance.management_ip,
-                                               reason=ex))
+            ip_used = "internal_ip" if CONF.proxy_command and \
+                CONF.proxy_command_use_internal_ip else "management_ip"
+            LOG.debug("Can't login to node, IP: {ip}, reason {reason}"
+                      .format(ip=getattr(instance, ip_used),
+                              reason=ex))
             return False
 
         return False
@@ -141,10 +144,10 @@ class Engine(object):
         """Configure active instances.
 
         * generate /etc/hosts
+        * change /etc/resolv.conf
         * setup passwordless login
         * etc.
         """
-        hosts_file = cluster_utils.generate_etc_hosts(cluster)
         cpo.add_provisioning_step(
             cluster.id, _("Configure instances"),
             cluster_utils.count_instances(cluster))
@@ -153,14 +156,20 @@ class Engine(object):
             for node_group in cluster.node_groups:
                 for instance in node_group.instances:
                     with context.set_current_instance_id(instance.instance_id):
-                        tg.spawn(
-                            "configure-instance-%s" % instance.instance_name,
-                            self._configure_instance, instance, hosts_file)
+                        tg.spawn("configure-instance-{}".format(
+                            instance.instance_name),
+                            self._configure_instance, instance, cluster
+                        )
 
     @cpo.event_wrapper(mark_successful_on_exit=True)
-    def _configure_instance(self, instance, hosts_file):
-        LOG.debug('Configuring instance')
+    def _configure_instance(self, instance, cluster):
+        self._configure_instance_etc_hosts(instance, cluster)
+        if cluster.use_designate_feature():
+            self._configure_instance_resolve_conf(instance)
 
+    def _configure_instance_etc_hosts(self, instance, cluster):
+        LOG.debug('Configuring "/etc/hosts" of instance.')
+        hosts_file = cluster_utils.generate_etc_hosts(cluster)
         with instance.remote() as r:
             r.write_file_to('etc-hosts', hosts_file)
             r.execute_command('sudo hostname %s' % instance.fqdn())
@@ -168,6 +177,23 @@ class Engine(object):
 
             r.execute_command('sudo usermod -s /bin/bash $USER')
 
+    def _configure_instance_resolve_conf(self, instance):
+        LOG.debug('Setting up those name servers from sahara.conf '
+                  'which are lacked in the /etc/resolv.conf.')
+        with instance.remote() as r:
+            code, curr_resolv_conf = r.execute_command('cat /etc/resolv.conf')
+            diff = cluster_utils.generate_resolv_conf_diff(curr_resolv_conf)
+            if diff.strip():
+                position = curr_resolv_conf.find('nameserver')
+                if position == -1:
+                    position = 0
+                new_resolv_conf = "{}\n{}{}".format(
+                    curr_resolv_conf[:position],
+                    diff,
+                    curr_resolv_conf[position:])
+                r.write_file_to('resolv-conf', new_resolv_conf)
+                r.execute_command('sudo mv resolv-conf /etc/resolv.conf')
+
     def _generate_user_data_script(self, node_group, instance_name):
         script = """#!/bin/bash
 echo "${public_key}" >> ${user_home}/.ssh/authorized_keys\n
@@ -219,44 +245,52 @@ sed '/^Defaults    requiretty*/ s/^/#/' -i /etc/sudoers\n
             security_group = b.execute_with_retries(client.get, name)
             if (security_group.name !=
                     g.generate_auto_security_group_name(node_group)):
-                LOG.warning(_LW("Auto security group for node group {name} is "
-                                "not found").format(name=node_group.name))
+                LOG.warning("Auto security group for node group {name} is "
+                            "not found".format(name=node_group.name))
                 return
             b.execute_with_retries(client.delete, name)
         except Exception:
-            LOG.warning(_LW("Failed to delete security group {name}").format(
+            LOG.warning("Failed to delete security group {name}".format(
                 name=name))
 
-    def _delete_aa_server_group(self, cluster):
+    def _delete_aa_server_groups(self, cluster):
         if cluster.anti_affinity:
-            server_group_name = g.generate_aa_group_name(cluster.name)
-            client = nova.client().server_groups
+            for i in range(1, cluster.anti_affinity_ratio):
+                server_group_name = g.generate_aa_group_name(cluster.name, i)
 
-            server_groups = b.execute_with_retries(client.findall,
-                                                   name=server_group_name)
-            if len(server_groups) == 1:
-                b.execute_with_retries(client.delete, server_groups[0].id)
+                client = nova.client().server_groups
+
+                server_groups = b.execute_with_retries(client.findall,
+                                                       name=server_group_name)
+                if len(server_groups) == 1:
+                    b.execute_with_retries(client.delete, server_groups[0].id)
+
+                '''In case the server group is created
+                using mitaka or older version'''
+                old_server_group_name = server_group_name.rsplit('-', 1)[0]
+                server_groups_old = b.execute_with_retries(
+                    client.findall,
+                    name=old_server_group_name)
+                if len(server_groups_old) == 1:
+                    b.execute_with_retries(client.delete,
+                                           server_groups_old[0].id)
 
     def _shutdown_instance(self, instance):
+        # Heat dissociates and deletes upon deletion of resources
+        # See OS::Neutron::FloatingIP and OS::Neutron::FloatingIPAssociation
         if instance.node_group.floating_ip_pool:
-            try:
-                b.execute_with_retries(networks.delete_floating_ip,
-                                       instance.instance_id)
-            except nova_exceptions.NotFound:
-                LOG.warning(_LW("Attempted to delete non-existent floating IP "
-                                "in pool {pool} from instance")
-                            .format(pool=instance.node_group.floating_ip_pool))
+            pass
 
         try:
             volumes.detach_from_instance(instance)
         except Exception:
-            LOG.warning(_LW("Detaching volumes from instance failed"))
+            LOG.warning("Detaching volumes from instance failed")
 
         try:
             b.execute_with_retries(nova.client().servers.delete,
                                    instance.instance_id)
         except nova_exceptions.NotFound:
-            LOG.warning(_LW("Attempted to delete non-existent instance"))
+            LOG.warning("Attempted to delete non-existent instance")
 
         conductor.instance_remove(context.ctx(), instance)
 
