@@ -20,7 +20,6 @@ from oslo_log import log as logging
 from sahara import conductor as c
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LW
 from sahara.service import engine as e
 from sahara.service.heat import commons as heat_common
 from sahara.service.heat import templates as ht
@@ -110,8 +109,8 @@ class HeatEngine(e.Engine):
 
         if rollback_info.get('shutdown', False):
             self._rollback_cluster_creation(cluster, reason)
-            LOG.warning(_LW("Cluster creation rollback "
-                            "(reason: {reason})").format(reason=reason))
+            LOG.warning("Cluster creation rollback "
+                        "(reason: {reason})".format(reason=reason))
 
             return False
 
@@ -120,8 +119,8 @@ class HeatEngine(e.Engine):
         if rollback_count or target_count:
             self._rollback_cluster_scaling(
                 cluster, rollback_count, target_count, reason)
-            LOG.warning(_LW("Cluster scaling rollback "
-                            "(reason: {reason})").format(reason=reason))
+            LOG.warning("Cluster scaling rollback "
+                        "(reason: {reason})".format(reason=reason))
 
             return True
 
@@ -153,11 +152,17 @@ class HeatEngine(e.Engine):
             instances = stack.get_node_group_instances(node_group)
             for instance in instances:
                 nova_id = instance['physical_id']
-                name = instance['name']
                 if nova_id not in old_ids:
-                    instance_id = conductor.instance_add(
-                        ctx, node_group, {"instance_id": nova_id,
-                                          "instance_name": name})
+                    name = instance['name']
+                    inst = {
+                        "instance_id": nova_id,
+                        "instance_name": name
+                    }
+                    if cluster.use_designate_feature():
+                        inst.update(
+                            {"dns_hostname":
+                                name + '.' + cluster.domain_name[:-1]})
+                    instance_id = conductor.instance_add(ctx, node_group, inst)
                     new_ids.append(instance_id)
 
         return new_ids
@@ -190,13 +195,13 @@ class HeatEngine(e.Engine):
         try:
             heat.delete_stack(cluster)
         except heat_exc.HTTPNotFound:
-            LOG.warning(_LW('Did not find stack for cluster. Trying to delete '
-                            'cluster manually.'))
+            LOG.warning('Did not find stack for cluster. Trying to delete '
+                        'cluster manually.')
 
             # Stack not found. Trying to delete cluster like direct engine
             #  do it
             self._shutdown_instances(cluster)
-            self._delete_aa_server_group(cluster)
+            self._delete_aa_server_groups(cluster)
 
         self._clean_job_executions(cluster)
         self._remove_db_objects(cluster)
@@ -234,6 +239,7 @@ class HeatEngine(e.Engine):
         cluster = c_u.change_cluster_status(cluster, stages[2])
 
         instances = c_u.get_instances(cluster, inst_ids)
+
         volumes.mount_to_instances(instances)
 
         self._configure_instances(cluster)
