@@ -22,7 +22,6 @@ from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LE
 from sahara.utils.openstack import keystone
 
 conductor = c.API
@@ -70,8 +69,7 @@ def create_trust(trustor, trustee, role_names, impersonation=True,
             trust_id=six.text_type(trust.id)))
         return trust.id
     except Exception as e:
-        LOG.error(_LE('Unable to create trust (reason: {reason})').format(
-            reason=e))
+        LOG.error('Unable to create trust (reason: {reason})'.format(reason=e))
         raise ex.CreationFailed(_('Failed to create trust'))
 
 
@@ -89,7 +87,7 @@ def create_trust_for_cluster(cluster, expires=True):
     if CONF.use_identity_api_v3 and not cluster.trust_id:
         trustor = keystone.auth()
         trustee = keystone.auth_for_admin(
-            project_name=CONF.keystone_authtoken.admin_tenant_name)
+            project_name=keystone.get_keystoneauth_cfg(CONF, 'project_name'))
 
         trust_id = create_trust(trustor=trustor,
                                 trustee=trustee,
@@ -117,8 +115,7 @@ def delete_trust(trustee, trust_id):
         LOG.debug('Deleted trust {trust_id}'.format(
             trust_id=six.text_type(trust_id)))
     except Exception as e:
-        LOG.error(_LE('Unable to delete trust (reason: {reason})').format(
-            reason=e))
+        LOG.error('Unable to delete trust (reason: {reason})'.format(reason=e))
         raise ex.DeletionFailed(
             _('Failed to delete trust {0}').format(trust_id))
 
@@ -156,7 +153,7 @@ def use_os_admin_auth_token(cluster):
     ctx = context.current()
     cluster = conductor.cluster_get(ctx, cluster)
     if CONF.use_identity_api_v3 and cluster.trust_id:
-        ctx.username = CONF.keystone_authtoken.admin_user
+        ctx.username = keystone.get_keystoneauth_cfg(CONF, 'username')
         ctx.tenant_id = cluster.tenant_id
         ctx.auth_plugin = keystone.auth_for_admin(
             trust_id=cluster.trust_id)
