@@ -28,6 +28,7 @@ from sahara.service.api import v10 as api
 from sahara.utils import general as g
 import sahara.utils.openstack.cinder as cinder
 from sahara.utils.openstack import images as sahara_images
+import sahara.utils.openstack.neutron as neutron
 import sahara.utils.openstack.nova as nova
 
 
@@ -104,10 +105,14 @@ def check_node_group_configs(plugin_name, hadoop_version, ng_configs,
 
 
 def check_all_configurations(data):
-    pl_confs = _get_plugin_configs(data['plugin_name'], data['hadoop_version'])
+    plugin_version = 'hadoop_version'
+    if data.get('plugin_version'):
+        plugin_version = 'plugin_version'
+
+    pl_confs = _get_plugin_configs(data['plugin_name'], data[plugin_version])
 
     if data.get('cluster_configs'):
-        check_node_group_configs(data['plugin_name'], data['hadoop_version'],
+        check_node_group_configs(data['plugin_name'], data[plugin_version],
                                  data['cluster_configs'],
                                  plugin_configs=pl_confs)
 
@@ -115,7 +120,7 @@ def check_all_configurations(data):
         check_duplicates_node_groups_names(data['node_groups'])
         for ng in data['node_groups']:
             check_node_group_basic_fields(data['plugin_name'],
-                                          data['hadoop_version'],
+                                          data[plugin_version],
                                           ng, pl_confs)
 
 # NodeGroup related checks
@@ -177,11 +182,11 @@ def check_flavor_exists(flavor_id):
 
 
 def check_security_groups_exist(security_groups):
-    security_group_list = nova.client().security_groups.list()
+    security_group_list = neutron.client().list_security_groups()
     allowed_groups = set()
-    for sg in security_group_list:
-        allowed_groups.add(six.text_type(sg.id))
-        allowed_groups.add(sg.name)
+    for sg in security_group_list['security_groups']:
+        allowed_groups.add(sg['name'])
+        allowed_groups.add(sg['id'])
 
     for sg in security_groups:
         if sg not in allowed_groups:
@@ -192,7 +197,7 @@ def check_security_groups_exist(security_groups):
 def check_floatingip_pool_exists(pool_id):
     network = None
     if CONF.use_neutron:
-        network = nova.get_network(id=pool_id)
+        network = neutron.get_network(pool_id)
     else:
         # tmckay-fp, whoa, this suggests that we allow floating_ip_pools with
         # nova?  Can that be true? Scour for this
@@ -258,11 +263,11 @@ def check_volume_type_exists(volume_type):
 
 # Cluster creation related checks
 
-def check_cluster_unique_name(name):
-    if name in [cluster.name for cluster in api.get_clusters(
-            tenant_id=context.ctx().tenant_id)]:
+def check_cluster_unique_name(cluster_name):
+    if cluster_name in [cluster.name for cluster in
+                        api.get_clusters(name=cluster_name)]:
         raise ex.NameAlreadyExistsException(
-            _("Cluster with name '%s' already exists") % name)
+            _("Cluster with name '%s' already exists") % cluster_name)
 
 
 def check_cluster_hostnames_lengths(cluster_name, node_groups):
@@ -288,17 +293,19 @@ def check_keypair_exists(keypair):
 
 
 def check_network_exists(net_id):
-    if not nova.get_network(id=net_id):
+    if not neutron.get_network(net_id):
         raise ex.NotFoundException(net_id, _("Network %s not found"))
 
 
 # Cluster templates related checks
 
-def check_cluster_template_unique_name(name):
-    if name in [t.name for t in api.get_cluster_templates(
-            tenant_id=context.ctx().tenant_id)]:
+def check_cluster_template_unique_name(cluster_tmpl_name):
+    if cluster_tmpl_name in [cluster_tmpl.name for cluster_tmpl in
+                             api.get_cluster_templates(
+                                 name=cluster_tmpl_name)]:
         raise ex.NameAlreadyExistsException(
-            _("Cluster template with name '%s' already exists") % name)
+            _("Cluster template with name '%s' already exists") %
+            cluster_tmpl_name)
 
 
 def check_cluster_template_exists(cluster_template_id):
@@ -320,11 +327,12 @@ def check_node_groups_in_cluster_templates(cluster_name, plugin_name,
 # NodeGroup templates related checks
 
 
-def check_node_group_template_unique_name(name):
-    if name in [t.name for t in api.get_node_group_templates(
-            tenant_id=context.ctx().tenant_id)]:
+def check_node_group_template_unique_name(ng_tmpl_name):
+    if ng_tmpl_name in [ng_tmpl.name for ng_tmpl in
+                        api.get_node_group_templates(name=ng_tmpl_name)]:
         raise ex.NameAlreadyExistsException(
-            _("NodeGroup template with name '%s' already exists") % name)
+            _("NodeGroup template with name '%s' already exists") %
+            ng_tmpl_name)
 
 
 def check_node_group_template_exists(ng_tmpl_id):
