@@ -20,9 +20,11 @@ from sahara import conductor as cond
 from sahara import context
 from sahara import exceptions as ex
 from sahara.plugins import base as pb
+from sahara.plugins import exceptions as pe
 from sahara.plugins.spark import plugin as pl
 from sahara.service.edp.spark import engine
 from sahara.tests.unit import base
+from sahara.tests.unit import testutils as tu
 from sahara.utils import edp
 
 
@@ -54,20 +56,32 @@ class SparkPluginTest(base.SaharaWithDbTestCase):
         edp_engine = plugin.get_edp_engine(cluster, edp.JOB_TYPE_SPARK)
         with testtools.ExpectedException(
                 ex.InvalidDataException,
-                value_re="Spark 1.0.0 or higher required to run "
+                value_re="Spark 1.3.1 or higher required to run "
                          "Spark jobs\nError ID: .*"):
             edp_engine.validate_job_execution(cluster, job, mock.Mock())
 
     def test_plugin10_edp_engine(self):
-        self._test_engine('1.0.0', edp.JOB_TYPE_SPARK,
+        self._test_engine('1.3.1', edp.JOB_TYPE_SPARK,
                           engine.SparkJobEngine)
 
-    def test_plugin09_shell_engine(self):
-        self._test_engine('0.9.1', edp.JOB_TYPE_SHELL,
+    def test_plugin10_shell_engine(self):
+        self._test_engine('1.3.1', edp.JOB_TYPE_SHELL,
                           engine.SparkShellJobEngine)
 
-    def test_plugin10_shell_engine(self):
-        self._test_engine('1.0.0', edp.JOB_TYPE_SHELL,
+    def test_plugin11_edp_engine(self):
+        self._test_engine('1.6.0', edp.JOB_TYPE_SPARK,
+                          engine.SparkJobEngine)
+
+    def test_plugin12_shell_engine(self):
+        self._test_engine('1.6.0', edp.JOB_TYPE_SHELL,
+                          engine.SparkShellJobEngine)
+
+    def test_plugin21_edp_engine(self):
+        self._test_engine('2.1.0', edp.JOB_TYPE_SPARK,
+                          engine.SparkJobEngine)
+
+    def test_plugin22_shell_engine(self):
+        self._test_engine('2.1.0', edp.JOB_TYPE_SHELL,
                           engine.SparkShellJobEngine)
 
     def _test_engine(self, version, job_type, eng):
@@ -100,7 +114,7 @@ class SparkPluginTest(base.SaharaWithDbTestCase):
             'cron': 'cron_text'}}
         instance.node_group.node_processes = ["master"]
         instance.node_group.id = id
-        cluster_dict = self._init_cluster_dict('1.0.0')
+        cluster_dict = self._init_cluster_dict('1.3.1')
 
         cluster = conductor.cluster_create(context.ctx(), cluster_dict)
         plugin = pb.PLUGINS.get_plugin(cluster.plugin_name)
@@ -124,6 +138,55 @@ class SparkPluginTest(base.SaharaWithDbTestCase):
             'sudo rm -f /etc/crond.d/spark-cleanup')
 
 
+class SparkValidationTest(base.SaharaTestCase):
+    def setUp(self):
+        super(SparkValidationTest, self).setUp()
+        pb.setup_plugins()
+        self.plugin = pl.SparkProvider()
+
+    def test_validate(self):
+        self.ng = []
+        self.ng.append(tu.make_ng_dict("nn", "f1", ["namenode"], 0))
+        self.ng.append(tu.make_ng_dict("ma", "f1", ["master"], 0))
+        self.ng.append(tu.make_ng_dict("sl", "f1", ["slave"], 0))
+        self.ng.append(tu.make_ng_dict("dn", "f1", ["datanode"], 0))
+
+        self._validate_case(1, 1, 3, 3)
+        self._validate_case(1, 1, 3, 4)
+        self._validate_case(1, 1, 4, 3)
+
+        with testtools.ExpectedException(pe.InvalidComponentCountException):
+            self._validate_case(2, 1, 3, 3)
+
+        with testtools.ExpectedException(pe.InvalidComponentCountException):
+            self._validate_case(1, 2, 3, 3)
+
+        with testtools.ExpectedException(pe.InvalidComponentCountException):
+            self._validate_case(0, 1, 3, 3)
+
+        with testtools.ExpectedException(pe.RequiredServiceMissingException):
+            self._validate_case(1, 0, 3, 3)
+
+        cl = self._create_cluster(
+            1, 1, 3, 3, cluster_configs={'HDFS': {'dfs.replication': 4}})
+
+        with testtools.ExpectedException(pe.InvalidComponentCountException):
+            self.plugin.validate(cl)
+
+    def _create_cluster(self, *args, **kwargs):
+        lst = []
+        for i in range(0, len(args)):
+            self.ng[i]['count'] = args[i]
+            lst.append(self.ng[i])
+
+        return tu.create_cluster("cluster1", "tenant1", "spark",
+                                 "1.60", lst, **kwargs)
+
+    def _validate_case(self, *args):
+        cl = self._create_cluster(*args)
+        self.plugin.validate(cl)
+
+
 class SparkProviderTest(base.SaharaTestCase):
     def setUp(self):
         super(SparkProviderTest, self).setUp()
@@ -132,26 +195,36 @@ class SparkProviderTest(base.SaharaTestCase):
         provider = pl.SparkProvider()
 
         res = provider.get_edp_job_types()
-        self.assertEqual([edp.JOB_TYPE_SHELL, edp.JOB_TYPE_SPARK],
-                         res['1.0.0'])
         self.assertEqual([edp.JOB_TYPE_SHELL, edp.JOB_TYPE_SPARK],
                          res['1.3.1'])
+        self.assertEqual([edp.JOB_TYPE_SHELL, edp.JOB_TYPE_SPARK],
+                         res['1.6.0'])
+        self.assertEqual([edp.JOB_TYPE_SHELL, edp.JOB_TYPE_SPARK],
+                         res['2.1.0'])
 
     def test_edp_config_hints(self):
         provider = pl.SparkProvider()
 
-        res = provider.get_edp_config_hints(edp.JOB_TYPE_SHELL, "1.0.0")
-        self.assertEqual({'configs': {}, 'args': [], 'params': {}},
-                         res['job_config'])
-
         res = provider.get_edp_config_hints(edp.JOB_TYPE_SHELL, "1.3.1")
         self.assertEqual({'configs': {}, 'args': [], 'params': {}},
                          res['job_config'])
 
-        res = provider.get_edp_config_hints(edp.JOB_TYPE_SPARK, "1.0.0")
-        self.assertEqual({'args': [], 'configs': []},
+        res = provider.get_edp_config_hints(edp.JOB_TYPE_SHELL, "1.6.0")
+        self.assertEqual({'configs': {}, 'args': [], 'params': {}},
                          res['job_config'])
 
         res = provider.get_edp_config_hints(edp.JOB_TYPE_SPARK, "1.3.1")
         self.assertEqual({'args': [], 'configs': []},
                          res['job_config'])
+
+        res = provider.get_edp_config_hints(edp.JOB_TYPE_SPARK, "1.6.0")
+        self.assertEqual({'args': [], 'configs': []},
+                         res['job_config'])
+
+        res = provider.get_edp_config_hints(edp.JOB_TYPE_SPARK, "2.1.0")
+        self.assertEqual({'args': [], 'configs': []},
+                         res['job_config'])
+
+        res = provider.get_edp_config_hints(edp.JOB_TYPE_SPARK, "2.1.0")
+        self.assertEqual({'args': [], 'configs': []},
+                         res['job_config'])
