@@ -23,7 +23,6 @@ from werkzeug import datastructures
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LE
 from sahara.utils import types
 from sahara.utils import wsgi
 
@@ -219,7 +218,8 @@ def render(res=None, resp_type=None, status=None, name=None, **kwargs):
         resp_type = RT_JSON
         serializer = wsgi.JSONDictSerializer()
     else:
-        abort_and_log(400, _("Content type '%s' isn't supported") % resp_type)
+        raise ex.InvalidDataException(
+            _("Content type '%s' isn't supported") % resp_type)
 
     body = serializer.serialize(res)
     resp_type = str(resp_type)
@@ -244,8 +244,8 @@ def request_data():
     if not content_type or content_type in RT_JSON:
         deserializer = wsgi.JSONDeserializer()
     else:
-        abort_and_log(400,
-                      _("Content type '%s' isn't supported") % content_type)
+        raise ex.InvalidDataException(
+            _("Content type '%s' isn't supported") % content_type)
 
     # parsed request data to avoid unwanted re-parsings
     parsed_data = deserializer.deserialize(flask.request.data)['body']
@@ -259,9 +259,8 @@ def get_request_args():
 
 
 def abort_and_log(status_code, descr, exc=None):
-    LOG.error(_LE("Request aborted with status code {code} and "
-                  "message '{message}'").format(code=status_code,
-                                                message=descr))
+    LOG.error("Request aborted with status code {code} and "
+              "message '{message}'".format(code=status_code, message=descr))
 
     if exc is not None:
         LOG.error(traceback.format_exc())
@@ -283,9 +282,8 @@ def render_error_message(error_code, error_message, error_name):
 
 
 def internal_error(status_code, descr, exc=None):
-    LOG.error(_LE("Request aborted with status code {code} and "
-                  "message '{message}'").format(code=status_code,
-                                                message=descr))
+    LOG.error("Request aborted with status code {code} and "
+              "message '{message}'".format(code=status_code, message=descr))
 
     if exc is not None:
         LOG.error(traceback.format_exc())
@@ -300,11 +298,11 @@ def internal_error(status_code, descr, exc=None):
 def bad_request(error):
     error_code = 400
 
-    LOG.error(_LE("Validation Error occurred: "
-                  "error_code={code}, error_message={message}, "
-                  "error_name={name}").format(code=error_code,
-                                              message=error.message,
-                                              name=error.code))
+    LOG.error("Validation Error occurred: "
+              "error_code={code}, error_message={message}, "
+              "error_name={name}".format(code=error_code,
+                                         message=error.message,
+                                         name=error.code))
 
     return render_error_message(error_code, error.message, error.code)
 
@@ -312,11 +310,10 @@ def bad_request(error):
 def access_denied(error):
     error_code = 403
 
-    LOG.error(_LE("Access Denied: "
-                  "error_code={code}, error_message={message}, "
-                  "error_name={name}").format(code=error_code,
-                                              message=error.message,
-                                              name=error.code))
+    LOG.error("Access Denied: error_code={code}, error_message={message}, "
+              "error_name={name}".format(code=error_code,
+                                         message=error.message,
+                                         name=error.code))
 
     return render_error_message(error_code, error.message, error.code)
 
@@ -324,20 +321,24 @@ def access_denied(error):
 def not_found(error):
     error_code = 404
 
-    LOG.error(_LE("Not Found exception occurred: "
-                  "error_code={code}, error_message={message}, "
-                  "error_name={name}").format(code=error_code,
-                                              message=error.message,
-                                              name=error.code))
+    LOG.error("Not Found exception occurred: "
+              "error_code={code}, error_message={message}, "
+              "error_name={name}".format(code=error_code,
+                                         message=error.message,
+                                         name=error.code))
 
     return render_error_message(error_code, error.message, error.code)
 
 
 def to_wrapped_dict(func, id, *args, **kwargs):
+    return render(to_wrapped_dict_no_render(func, id, *args, **kwargs))
+
+
+def to_wrapped_dict_no_render(func, id, *args, **kwargs):
     obj = func(id, *args, **kwargs)
     if obj is None:
         e = ex.NotFoundException(
             {'id': id}, _('Object with %s not found'))
 
         return not_found(e)
-    return render(obj.to_wrapped_dict())
+    return obj.to_wrapped_dict()
